@@ -48,17 +48,18 @@ ggbarstats <- function(data,
                        x,
                        y,
                        counts = NULL,
-                       ratio = NULL,
+                       type = "parametric",
                        paired = FALSE,
                        results.subtitle = TRUE,
                        sample.size.label = TRUE,
                        label = "percentage",
                        label.args = list(alpha = 1, fill = "white"),
-                       conf.level = 0.95,
                        k = 2L,
                        proportion.test = TRUE,
                        perc.k = 0,
                        bf.message = TRUE,
+                       ratio = NULL,
+                       conf.level = 0.95,
                        sampling.plan = "indepMulti",
                        fixed.margin = "rows",
                        prior.concentration = 1,
@@ -75,20 +76,12 @@ ggbarstats <- function(data,
                        ggplot.component = NULL,
                        output = "plot",
                        ...) {
+  # convert entered stats type to a standard notation
+  type <- ipmisc::stats_type_switch(type)
+
   # make sure both quoted and unquoted arguments are allowed
   c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
 
-  # this is currently not supported in `BayesFactor`
-  if (isTRUE(paired)) bf.message <- FALSE
-
-  # ================= extracting column names as labels  =====================
-
-  # if legend title is not provided, use the 'x' variable name
-  if (rlang::is_null(legend.title)) legend.title <- rlang::as_name(x)
-
-  # if x-axis label is not specified, use the 'y' variable
-  if (is.null(xlab)) xlab <- rlang::as_name(y)
-
   # =============================== dataframe ================================
 
   # creating a dataframe
@@ -97,20 +90,17 @@ ggbarstats <- function(data,
     tidyr::drop_na(.)
 
   # untable the dataframe based on the count for each observation
-  if (".counts" %in% names(data)) data %<>% tidyr::uncount(data = ., weights = .counts)
+  if (".counts" %in% names(data)) data %<>% tidyr::uncount(weights = .counts)
 
   # x and y need to be a factor; also drop the unused levels of the factors
   data %<>% dplyr::mutate(dplyr::across(dplyr::everything(), ~ droplevels(as.factor(.x))))
 
   # TO DO: until one-way table is supported by `BayesFactor`
-  if (nlevels(data %>% dplyr::pull({{ y }})) == 1L) {
-    c(bf.message, proportion.test) %<-% c(FALSE, FALSE)
-  }
+  if (nlevels(data %>% dplyr::pull({{ y }})) == 1L) c(bf.message, proportion.test) %<-% c(FALSE, FALSE)
 
-  # ========================= statistical analysis ===========================
+  # -------------------------- statistical analysis --------------------------
 
-  # running appropriate statistical test
-  # unpaired: Pearson's Chi-square test of independence
+  # if subtitle with results is to be displayed
   if (isTRUE(results.subtitle)) {
     subtitle <-
       tryCatch(
@@ -118,16 +108,17 @@ ggbarstats <- function(data,
           data = data,
           x = {{ x }},
           y = {{ y }},
-          ratio = ratio,
+          type = type,
+          k = k,
           paired = paired,
-          conf.level = conf.level,
-          k = k
+          ratio = ratio,
+          conf.level = conf.level
         ),
         error = function(e) NULL
       )
 
-    # preparing the BF message for null hypothesis support
-    if (isTRUE(bf.message) && !is.null(subtitle)) {
+    # preparing Bayes Factor caption
+    if (type != "bayes" && isTRUE(bf.message) && isFALSE(paired)) {
       caption <-
         tryCatch(
           expr = statsExpressions::expr_contingency_tab(
@@ -135,12 +126,11 @@ ggbarstats <- function(data,
             x = {{ x }},
             y = {{ y }},
             type = "bayes",
+            k = k,
+            top.text = caption,
             sampling.plan = sampling.plan,
             fixed.margin = fixed.margin,
-            prior.concentration = prior.concentration,
-            top.text = caption,
-            output = "caption",
-            k = k
+            prior.concentration = prior.concentration
           ),
           error = function(e) NULL
         )
@@ -149,7 +139,10 @@ ggbarstats <- function(data,
 
   # return early if anything other than plot
   if (output != "plot") {
-    return(switch(EXPR = output, "caption" = caption, subtitle))
+    return(switch(EXPR = output,
+      "caption" = caption,
+      subtitle
+    ))
   }
 
   # =================================== plot =================================
@@ -161,11 +154,7 @@ ggbarstats <- function(data,
   df_proptest <- df_proptest(data, {{ x }}, {{ y }}, k)
 
   # if no. of factor levels is greater than the default palette color count
-  palette_message(
-    package = package,
-    palette = palette,
-    min_length = nlevels(data %>% dplyr::pull({{ x }}))[[1]]
-  )
+  palette_message(package, palette, min_length = nlevels(data %>% dplyr::pull({{ x }}))[[1]])
 
   # plot
   p <-
@@ -189,12 +178,11 @@ ggbarstats <- function(data,
       mapping = ggplot2::aes(label = .label, group = {{ x }}),
       show.legend = FALSE,
       position = ggplot2::position_fill(vjust = 0.5),
-      na.rm = TRUE,
       !!!label.args
     ) +
-    theme_ggstatsplot(ggtheme = ggtheme, ggstatsplot.layer = ggstatsplot.layer) +
+    theme_ggstatsplot(ggtheme, ggstatsplot.layer) +
     ggplot2::theme(panel.grid.major.x = ggplot2::element_blank()) +
-    ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title)) +
+    ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title %||% rlang::as_name(x))) +
     paletteer::scale_fill_paletteer_d(palette = paste0(package, "::", palette), name = "")
 
   # ================ sample size and proportion test labels ===================
@@ -207,7 +195,6 @@ ggbarstats <- function(data,
         data = df_proptest,
         mapping = ggplot2::aes(x = {{ y }}, y = 1.05, label = .p.label, fill = NULL),
         size = 2.8,
-        na.rm = TRUE,
         parse = TRUE
       )
   }
@@ -228,7 +215,7 @@ ggbarstats <- function(data,
   # preparing the plot
   p +
     ggplot2::labs(
-      x = xlab,
+      x = xlab %||% rlang::as_name(y),
       y = ylab,
       subtitle = subtitle,
       title = title,
