@@ -41,7 +41,7 @@
 #' @import ggplot2
 #'
 #' @importFrom dplyr select mutate vars pull across everything
-#' @importFrom rlang !! enquo as_name ensym
+#' @importFrom rlang !! enquo as_name ensym !!! exec
 #' @importFrom ggrepel geom_label_repel
 #' @importFrom paletteer scale_fill_paletteer_d
 #' @importFrom tidyr uncount drop_na
@@ -72,17 +72,18 @@ ggpiestats <- function(data,
                        x,
                        y = NULL,
                        counts = NULL,
-                       ratio = NULL,
+                       type = "parametric",
                        paired = FALSE,
                        results.subtitle = TRUE,
                        label = "percentage",
                        label.args = list(direction = "both"),
                        label.repel = FALSE,
-                       conf.level = 0.95,
                        k = 2L,
                        proportion.test = TRUE,
                        perc.k = 0,
                        bf.message = TRUE,
+                       ratio = NULL,
+                       conf.level = 0.95,
                        sampling.plan = "indepMulti",
                        fixed.margin = "rows",
                        prior.concentration = 1,
@@ -97,6 +98,8 @@ ggpiestats <- function(data,
                        ggplot.component = NULL,
                        output = "plot",
                        ...) {
+  # convert entered stats type to a standard notation
+  type <- ipmisc::stats_type_switch(type)
 
   # ensure the variables work quoted or unquoted
   x <- rlang::ensym(x)
@@ -105,12 +108,6 @@ ggpiestats <- function(data,
   # one-way or two-way table?
   test <- ifelse(!rlang::quo_is_null(rlang::enquo(y)), "two.way", "one.way")
 
-  # this is currently not supported in `BayesFactor`
-  if (isTRUE(paired)) bf.message <- FALSE
-
-  # saving the column label for the 'x' variables
-  if (rlang::is_null(legend.title)) legend.title <- rlang::as_name(x)
-
   # =============================== dataframe ================================
 
   # creating a dataframe
@@ -119,7 +116,7 @@ ggpiestats <- function(data,
     tidyr::drop_na(.)
 
   # untable the dataframe based on the count for each observation
-  if (".counts" %in% names(data)) data %<>% tidyr::uncount(data = ., weights = .counts)
+  if (".counts" %in% names(data)) data %<>% tidyr::uncount(weights = .counts)
 
   # x and y need to be a factor; also drop the unused levels of the factors
   data %<>% dplyr::mutate(dplyr::across(dplyr::everything(), ~ droplevels(as.factor(.x))))
@@ -128,7 +125,7 @@ ggpiestats <- function(data,
   x_levels <- nlevels(data %>% dplyr::pull({{ x }}))[[1]]
 
   # y
-  if (!rlang::quo_is_null(rlang::enquo(y))) {
+  if (test == "two.way") {
     y_levels <- nlevels(data %>% dplyr::pull({{ y }}))[[1]]
 
     # TO DO: until one-way table is supported by `BayesFactor`
@@ -137,11 +134,11 @@ ggpiestats <- function(data,
     y_levels <- 0L
   }
 
-  # facting is happening only if both vars have more than one levels
+  # faceting is happening only if both vars have more than one levels
   facet <- ifelse(y_levels > 1L, TRUE, FALSE)
   if (x_levels == 1L && isTRUE(facet)) proportion.test <- FALSE
 
-  # ========================= statistical analysis ==========================
+  # -------------------------- statistical analysis --------------------------
 
   # if subtitle with results is to be displayed
   if (isTRUE(results.subtitle)) {
@@ -151,16 +148,17 @@ ggpiestats <- function(data,
           data = data,
           x = {{ x }},
           y = {{ y }},
-          ratio = ratio,
+          type = type,
+          k = k,
           paired = paired,
-          conf.level = conf.level,
-          k = k
+          ratio = ratio,
+          conf.level = conf.level
         ),
         error = function(e) NULL
       )
 
     # preparing Bayes Factor caption
-    if (isTRUE(bf.message) && !is.null(subtitle)) {
+    if (type != "bayes" && isTRUE(bf.message) && isFALSE(paired)) {
       caption <-
         tryCatch(
           expr = statsExpressions::expr_contingency_tab(
@@ -168,12 +166,11 @@ ggpiestats <- function(data,
             x = {{ x }},
             y = {{ y }},
             type = "bayes",
+            k = k,
+            top.text = caption,
             sampling.plan = sampling.plan,
             fixed.margin = fixed.margin,
-            prior.concentration = prior.concentration,
-            top.text = caption,
-            output = "caption",
-            k = k
+            prior.concentration = prior.concentration
           ),
           error = function(e) NULL
         )
@@ -182,7 +179,10 @@ ggpiestats <- function(data,
 
   # return early if anything other than plot
   if (output != "plot") {
-    return(switch(EXPR = output, "caption" = caption, subtitle))
+    return(switch(EXPR = output,
+      "caption" = caption,
+      subtitle
+    ))
   }
 
   # =================================== plot =================================
@@ -194,11 +194,7 @@ ggpiestats <- function(data,
   if (test == "two.way") df_proptest <- df_proptest(data, {{ x }}, {{ y }}, k)
 
   # if no. of factor levels is greater than the default palette color count
-  palette_message(
-    package = package,
-    palette = palette,
-    min_length = x_levels
-  )
+  palette_message(package, palette, min_length = x_levels)
 
   # creating the basic plot
   p <-
@@ -224,7 +220,6 @@ ggpiestats <- function(data,
       min.segment.length = 0,
       fill = "white",
       alpha = 1,
-      na.rm = TRUE,
       !!!label.args
     )))
 
@@ -236,7 +231,7 @@ ggpiestats <- function(data,
     ggplot2::coord_polar(theta = "y") +
     ggplot2::scale_y_continuous(breaks = NULL) +
     paletteer::scale_fill_paletteer_d(palette = paste0(package, "::", palette), name = "") +
-    theme_pie(ggtheme = ggtheme, ggstatsplot.layer = ggstatsplot.layer) +
+    theme_pie(ggtheme, ggstatsplot.layer) +
     ggplot2::guides(fill = ggplot2::guide_legend(override.aes = list(color = NA)))
 
   # ================ sample size + proportion test labels =================
@@ -250,7 +245,6 @@ ggpiestats <- function(data,
         mapping = ggplot2::aes(label = .label, x = 1.65, y = 0.5),
         position = ggplot2::position_fill(vjust = 1),
         size = 2.8,
-        na.rm = TRUE,
         parse = TRUE
       )
   }
@@ -266,6 +260,6 @@ ggpiestats <- function(data,
       title = title,
       caption = caption
     ) +
-    ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title)) +
+    ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title %||% rlang::as_name(x))) +
     ggplot.component
 }
