@@ -14,9 +14,9 @@
 #' 1. Please note that the function expects that the data is
 #'   already sorted by subject/repeated measures ID.
 #'
-#' 2. To get the Bayes Factor message, you are going to need to install
-#'   the development version of `BayesFactor` (`0.9.12-4.3`).
-#'   You can download it by running:
+#' 2. To carry out Bayesian analysis for ANOVA designs, you will need to install
+#' the development version of `BayesFactor` (`0.9.12-4.3`). You can download it
+#' by running:
 #' `remotes::install_github("richarddmorey/BayesFactor/pkg/BayesFactor")`.
 #'
 #' @inheritParams ggbetweenstats
@@ -92,16 +92,15 @@ ggwithinstats <- function(data,
                           k = 2L,
                           conf.level = 0.95,
                           nboot = 100L,
-                          tr = 0.1,
+                          tr = 0.2,
                           centrality.plotting = TRUE,
+                          centrality.type = type,
                           centrality.point.args = list(size = 5, color = "darkred"),
                           centrality.label.args = list(size = 3, nudge_x = 0.4, segment.linetype = 4),
-                          point.path = TRUE,
-                          point.path.args = list(alpha = 0.5, linetype = "dashed"),
                           centrality.path = TRUE,
                           centrality.path.args = list(color = "red", size = 1, alpha = 0.5),
-                          notch = FALSE,
-                          notchwidth = 0.5,
+                          point.path = TRUE,
+                          point.path.args = list(alpha = 0.5, linetype = "dashed"),
                           outlier.tagging = FALSE,
                           outlier.label = NULL,
                           outlier.coef = 1.5,
@@ -119,58 +118,46 @@ ggwithinstats <- function(data,
   # convert entered stats type to a standard notation
   type <- ipmisc::stats_type_switch(type)
 
-  # ------------------------------ variable names ----------------------------
-
   # ensure the variables work quoted or unquoted
-  x <- rlang::ensym(x)
-  y <- rlang::ensym(y)
+  c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
   outlier.label <- if (!rlang::quo_is_null(rlang::enquo(outlier.label))) {
     rlang::ensym(outlier.label)
   }
 
-  # if `xlab` and `ylab` is not provided, use the variable `x` and `y` name
-  if (is.null(xlab)) xlab <- rlang::as_name(x)
-  if (is.null(ylab)) ylab <- rlang::as_name(y)
-
   # --------------------------------- data -----------------------------------
 
   # creating a dataframe
   data %<>%
     dplyr::select({{ x }}, {{ y }}, outlier.label = {{ outlier.label }}) %>%
     dplyr::mutate({{ x }} := droplevels(as.factor({{ x }}))) %>%
-    as_tibble(.) %>%
     dplyr::group_by({{ x }}) %>%
-    dplyr::mutate(rowid = dplyr::row_number()) %>%
+    dplyr::mutate(.rowid = dplyr::row_number()) %>%
     dplyr::ungroup(.) %>%
-    dplyr::anti_join(x = ., y = dplyr::filter(., is.na({{ y }})), by = "rowid")
+    dplyr::anti_join(x = ., y = dplyr::filter(., is.na({{ y }})), by = ".rowid")
 
   # if `outlier.label` column is not present, just use the values from `y` column
-  if (rlang::quo_is_null(rlang::enquo(outlier.label))) {
-    data %<>% dplyr::mutate(outlier.label = {{ y }})
-  }
+  if (!"outlier.label" %in% names(data)) data %<>% dplyr::mutate(outlier.label = {{ y }})
 
   # add a logical column indicating whether a point is or is not an outlier
   data %<>%
     outlier_df(
-      data = .,
       x = {{ x }},
       y = {{ y }},
       outlier.coef = outlier.coef,
       outlier.label = outlier.label
     )
 
-  # figure out which test to run based on the number of levels of the
-  # independent variables
+  # --------------------- subtitle/caption preparation ------------------------
+
+  # figure out which test to run based on the no. of levels of the independent variable
   test <- ifelse(nlevels(data %>% dplyr::pull({{ x }}))[[1]] < 3, "t", "anova")
 
-  if (type == "parametric" && test == "anova" &&
-    utils::packageVersion("BayesFactor") < package_version("0.9.12-4.3")) {
-    message('To get Bayes Factor, install GitHub version of `BayesFactor`:\n remotes::install_github("richarddmorey/BayesFactor/pkg/BayesFactor")')
-    bf.message <- FALSE
+  # these analyses do require latest Github version of Bayes Factor
+  if (type %in% c("parametric", "bayes") && test == "anova" &&
+    utils::packageVersion("BayesFactor") < "0.9.12-4.3") {
+    if (type == "parametric") bf.message <- FALSE else results.subtitle <- FALSE
   }
 
-  # --------------------- subtitle/caption preparation ------------------------
-
   if (isTRUE(results.subtitle)) {
     # preparing the bayes factor message
     if (type == "parametric" && isTRUE(bf.message)) {
@@ -212,7 +199,10 @@ ggwithinstats <- function(data,
 
   # return early if anything other than plot
   if (output != "plot") {
-    return(switch(output, "caption" = caption, subtitle))
+    return(switch(output,
+      "caption" = caption,
+      subtitle
+    ))
   }
 
   # --------------------------------- basic plot ------------------------------
@@ -221,12 +211,11 @@ ggwithinstats <- function(data,
   plot <-
     ggplot2::ggplot(
       data = data,
-      mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}, group = rowid)
+      mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}, group = .rowid)
     ) +
     ggplot2::geom_point(
       alpha = 0.5,
       size = 3,
-      na.rm = TRUE,
       ggplot2::aes(color = {{ x }})
     ) +
     ggplot2::geom_boxplot(
@@ -234,16 +223,13 @@ ggwithinstats <- function(data,
       inherit.aes = FALSE,
       fill = "white",
       width = 0.2,
-      alpha = 0.5,
-      notch = notch,
-      notchwidth = notchwidth
+      alpha = 0.5
     ) +
     rlang::exec(
       .fn = ggplot2::geom_violin,
       mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}),
       inherit.aes = FALSE,
       fill = "white",
-      na.rm = TRUE,
       !!!violin.args
     )
 
@@ -252,7 +238,6 @@ ggwithinstats <- function(data,
     plot <- plot +
       rlang::exec(
         .fn = ggplot2::geom_path,
-        na.rm = TRUE,
         !!!point.path.args
       )
   }
@@ -273,7 +258,6 @@ ggwithinstats <- function(data,
         show.legend = FALSE,
         min.segment.length = 0,
         inherit.aes = FALSE,
-        na.rm = TRUE,
         !!!outlier.label.args
       )
   }
@@ -289,7 +273,7 @@ ggwithinstats <- function(data,
         x = {{ x }},
         y = {{ y }},
         k = k,
-        type = type,
+        type = ipmisc::stats_type_switch(centrality.type),
         tr = tr,
         sample.size.label = sample.size.label,
         centrality.path = centrality.path,
@@ -344,8 +328,8 @@ ggwithinstats <- function(data,
   aesthetic_addon(
     plot = plot,
     x = data %>% dplyr::pull({{ x }}),
-    xlab = xlab,
-    ylab = ylab,
+    xlab = xlab %||% rlang::as_name(x),
+    ylab = ylab %||% rlang::as_name(y),
     title = title,
     subtitle = subtitle,
     caption = caption,
