@@ -7,7 +7,7 @@
 #'
 #' Helper function for `ggstatsplot::ggbarstats` to apply this function across
 #' multiple levels of a given factor and combining the resulting plots using
-#' `ggstatsplot::combine_plots2`.
+#' `ggstatsplot::combine_plots`.
 #'
 #' @inheritParams ggbarstats
 #' @inheritParams grouped_ggbetweenstats
@@ -16,8 +16,8 @@
 #' @import ggplot2
 #'
 #' @importFrom dplyr select
-#' @importFrom rlang enquo quo_name ensym
-#' @importFrom purrr map
+#' @importFrom rlang quo_name ensym
+#' @importFrom purrr pmap
 #'
 #' @seealso \code{\link{ggbarstats}}, \code{\link{ggpiestats}},
 #'  \code{\link{grouped_ggpiestats}}
@@ -58,14 +58,9 @@ grouped_ggbarstats <- function(data,
                                grouping.var,
                                title.prefix = NULL,
                                output = "plot",
-                               ...,
                                plotgrid.args = list(),
-                               title.text = NULL,
-                               title.args = list(size = 16, fontface = "bold"),
-                               caption.text = NULL,
-                               caption.args = list(size = 10),
-                               sub.text = NULL,
-                               sub.args = list(size = 12)) {
+                               annotation.args = list(),
+                               ...) {
 
   # ======================== preparing dataframe =============================
 
@@ -75,7 +70,7 @@ grouped_ggbarstats <- function(data,
   # creating a dataframe
   df <-
     dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}, {{ counts }}) %>%
-    grouped_list(data = ., grouping.var = {{ grouping.var }})
+    grouped_list(grouping.var = {{ grouping.var }})
 
   # ================ creating a list of return objects ========================
 
@@ -94,16 +89,7 @@ grouped_ggbarstats <- function(data,
 
   # combining the list of plots into a single plot
   if (output == "plot") {
-    return(ggstatsplot::combine_plots2(
-      plotlist = plotlist_purrr,
-      plotgrid.args = plotgrid.args,
-      title.text = title.text,
-      title.args = title.args,
-      caption.text = caption.text,
-      caption.args = caption.args,
-      sub.text = sub.text,
-      sub.args = sub.args
-    ))
+    return(combine_plots(plotlist_purrr, plotgrid.args = plotgrid.args, annotation.args = annotation.args))
   } else {
     return(plotlist_purrr) # subtitle list
   }
