@@ -8,14 +8,14 @@
 #'
 #' Helper function for `ggstatsplot::ggbetweenstats` to apply this function
 #' across multiple levels of a given factor and combining the resulting plots
-#' using `ggstatsplot::combine_plots2`.
+#' using `ggstatsplot::combine_plots`.
 #'
 #' @param title.prefix Character string specifying the prefix text for the fixed
 #'   plot title (name of each factor level) (Default: `NULL`). If `NULL`, the
 #'   variable name entered for `grouping.var` will be used.
 #' @inheritParams ggbetweenstats
 #' @inheritParams grouped_list
-#' @inheritParams combine_plots2
+#' @inheritParams combine_plots
 #' @inheritDotParams ggbetweenstats -title
 #'
 #' @import ggplot2
@@ -70,14 +70,9 @@ grouped_ggbetweenstats <- function(data,
                                    outlier.label = NULL,
                                    title.prefix = NULL,
                                    output = "plot",
-                                   ...,
                                    plotgrid.args = list(),
-                                   title.text = NULL,
-                                   title.args = list(size = 16, fontface = "bold"),
-                                   caption.text = NULL,
-                                   caption.args = list(size = 10),
-                                   sub.text = NULL,
-                                   sub.args = list(size = 12)) {
+                                   annotation.args = list(),
+                                   ...) {
 
   # ======================== preparing dataframe ==========================
 
@@ -86,9 +81,8 @@ grouped_ggbetweenstats <- function(data,
 
   # creating a dataframe
   df <-
-    data %>%
-    dplyr::select({{ grouping.var }}, {{ x }}, {{ y }}, {{ outlier.label }}) %>%
-    grouped_list(data = ., grouping.var = {{ grouping.var }})
+    dplyr::select(data, {{ grouping.var }}, {{ x }}, {{ y }}, {{ outlier.label }}) %>%
+    grouped_list(grouping.var = {{ grouping.var }})
 
   # ============== creating a list of plots using `pmap`=======================
 
@@ -106,16 +100,7 @@ grouped_ggbetweenstats <- function(data,
 
   # combining the list of plots into a single plot
   if (output == "plot") {
-    return(ggstatsplot::combine_plots2(
-      plotlist = plotlist_purrr,
-      plotgrid.args = plotgrid.args,
-      title.text = title.text,
-      title.args = title.args,
-      caption.text = caption.text,
-      caption.args = caption.args,
-      sub.text = sub.text,
-      sub.args = sub.args
-    ))
+    return(combine_plots(plotlist_purrr, plotgrid.args = plotgrid.args, annotation.args = annotation.args))
   } else {
     return(plotlist_purrr) # subtitle list
   }
