@@ -8,7 +8,7 @@
 #'
 #' Helper function for `ggstatsplot::ggcorrmat` to apply this function across
 #' multiple levels of a given factor and combining the resulting plots using
-#' `ggstatsplot::combine_plots2`.
+#' `ggstatsplot::combine_plots`.
 #'
 #' @inheritParams ggcorrmat
 #' @inheritParams grouped_ggbetweenstats
@@ -50,18 +50,12 @@
 # defining the function
 grouped_ggcorrmat <- function(data,
                               cor.vars = NULL,
-                              cor.vars.names = NULL,
                               grouping.var,
                               title.prefix = NULL,
                               output = "plot",
-                              ...,
                               plotgrid.args = list(),
-                              title.text = NULL,
-                              title.args = list(size = 16, fontface = "bold"),
-                              caption.text = NULL,
-                              caption.args = list(size = 10),
-                              sub.text = NULL,
-                              sub.args = list(size = 12)) {
+                              annotation.args = list(),
+                              ...) {
 
   # ========================= preparing dataframe =============================
 
@@ -88,7 +82,6 @@ grouped_ggcorrmat <- function(data,
     purrr::pmap(
       .l = list(data = df, title = paste0(title.prefix, ": ", names(df))),
       .f = ggstatsplot::ggcorrmat,
-      cor.vars.names = cor.vars.names,
       output = output,
       ...
     )
@@ -98,15 +91,11 @@ grouped_ggcorrmat <- function(data,
   # combining the list of plots into a single plot
   # inform user this can't be modified further with ggplot commands
   if (output == "plot") {
-    return(ggstatsplot::combine_plots2(
+    return(combine_plots(
       plotlist = plotlist_purrr,
+      guides = "keep", # each legend is going to be different
       plotgrid.args = plotgrid.args,
-      title.text = title.text,
-      title.args = title.args,
-      caption.text = caption.text,
-      caption.args = caption.args,
-      sub.text = sub.text,
-      sub.args = sub.args
+      annotation.args = annotation.args
     ))
   } else {
     return(dplyr::bind_rows(plotlist_purrr, .id = title.prefix))
