@@ -7,7 +7,7 @@
 #'
 #' Helper function for `ggstatsplot::ggdotplotstats` to apply this function
 #' across multiple levels of a given factor and combining the resulting plots
-#' using `ggstatsplot::combine_plots2`.
+#' using `ggstatsplot::combine_plots`.
 #'
 #' @inheritParams ggdotplotstats
 #' @inheritParams grouped_ggbetweenstats
@@ -55,14 +55,9 @@ grouped_ggdotplotstats <- function(data,
                                    grouping.var,
                                    title.prefix = NULL,
                                    output = "plot",
-                                   ...,
                                    plotgrid.args = list(),
-                                   title.text = NULL,
-                                   title.args = list(size = 16, fontface = "bold"),
-                                   caption.text = NULL,
-                                   caption.args = list(size = 10),
-                                   sub.text = NULL,
-                                   sub.args = list(size = 12)) {
+                                   annotation.args = list(),
+                                   ...) {
 
   # ======================== preparing dataframe ============================
 
@@ -72,7 +67,7 @@ grouped_ggdotplotstats <- function(data,
   # creating a dataframe
   df <-
     dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}) %>%
-    grouped_list(data = ., grouping.var = {{ grouping.var }})
+    grouped_list(grouping.var = {{ grouping.var }})
 
   # creating a list of plots
   plotlist_purrr <-
@@ -87,16 +82,7 @@ grouped_ggdotplotstats <- function(data,
 
   # combining the list of plots into a single plot
   if (output == "plot") {
-    return(ggstatsplot::combine_plots2(
-      plotlist = plotlist_purrr,
-      plotgrid.args = plotgrid.args,
-      title.text = title.text,
-      title.args = title.args,
-      caption.text = caption.text,
-      caption.args = caption.args,
-      sub.text = sub.text,
-      sub.args = sub.args
-    ))
+    return(combine_plots(plotlist_purrr, plotgrid.args = plotgrid.args, annotation.args = annotation.args))
   } else {
     return(plotlist_purrr) # subtitle list
   }
