@@ -8,16 +8,15 @@
 #'
 #' Helper function for `ggstatsplot::gghistostats` to apply this function
 #' across multiple levels of a given factor and combining the resulting plots
-#' using `ggstatsplot::combine_plots2`.
+#' using `ggstatsplot::combine_plots`.
 #'
 #' @inheritParams gghistostats
 #' @inheritParams grouped_ggbetweenstats
 #' @inheritDotParams gghistostats -title
 #'
-#' @importFrom dplyr select bind_rows
+#' @importFrom dplyr select
 #' @importFrom rlang ensym as_name
 #' @importFrom purrr pmap
-#' @importFrom tidyr drop_na
 #'
 #' @seealso \code{\link{gghistostats}}, \code{\link{ggdotplotstats}},
 #'  \code{\link{grouped_ggdotplotstats}}
@@ -41,7 +40,8 @@
 #'     ggplot2::scale_x_continuous(breaks = seq(3, 9, 1), limits = (c(3, 9))),
 #'     ggplot2::scale_y_continuous(breaks = seq(0, 25, 5), limits = (c(0, 25)))
 #'   ),
-#'   plotgrid.args = list(nrow = 1, labels = c("(i)", "(ii)", "(iii)")),
+#'   plotgrid.args = list(nrow = 1),
+#'   annotation.args = list(tag_levels = "i"),
 #' )
 #' }
 #' @export
@@ -54,32 +54,17 @@ grouped_gghistostats <- function(data,
                                  binwidth = NULL,
                                  title.prefix = NULL,
                                  output = "plot",
-                                 ...,
                                  plotgrid.args = list(),
-                                 title.text = NULL,
-                                 title.args = list(size = 16, fontface = "bold"),
-                                 caption.text = NULL,
-                                 caption.args = list(size = 10),
-                                 sub.text = NULL,
-                                 sub.args = list(size = 12)) {
+                                 annotation.args = list(),
+                                 ...) {
 
   # ======================== computing binwidth ============================
 
-  # ensure the grouping variable works quoted or unquoted
-  grouping.var <- rlang::ensym(grouping.var)
-
-  # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) title.prefix <- rlang::as_name(grouping.var)
-
   # maximum value for x
-  binmax <-
-    dplyr::select(.data = data, {{ x }}) %>%
-    max(x = ., na.rm = TRUE)
+  binmax <- max(dplyr::select(.data = data, {{ x }}), na.rm = TRUE)
 
   # minimum value for x
-  binmin <-
-    dplyr::select(.data = data, {{ x }}) %>%
-    min(x = ., na.rm = TRUE)
+  binmin <- min(dplyr::select(.data = data, {{ x }}), na.rm = TRUE)
 
   # number of datapoints
   bincount <- as.integer(data %>% dplyr::count(.))
@@ -89,10 +74,13 @@ grouped_gghistostats <- function(data,
 
   # ======================== preparing dataframe ============================
 
+  # if `title.prefix` is not provided, use the variable `grouping.var` name
+  if (is.null(title.prefix)) title.prefix <- rlang::as_name(rlang::ensym(grouping.var))
+
   # getting the dataframe ready
   df <-
     dplyr::select(.data = data, {{ grouping.var }}, {{ x }}) %>%
-    grouped_list(data = ., grouping.var = {{ grouping.var }})
+    grouped_list(grouping.var = {{ grouping.var }})
 
   # creating a list of plots
   plotlist_purrr <-
@@ -108,16 +96,7 @@ grouped_gghistostats <- function(data,
 
   # combining the list of plots into a single plot
   if (output == "plot") {
-    return(ggstatsplot::combine_plots2(
-      plotlist = plotlist_purrr,
-      plotgrid.args = plotgrid.args,
-      title.text = title.text,
-      title.args = title.args,
-      caption.text = caption.text,
-      caption.args = caption.args,
-      sub.text = sub.text,
-      sub.args = sub.args
-    ))
+    return(combine_plots(plotlist_purrr, plotgrid.args = plotgrid.args, annotation.args = annotation.args))
   } else {
     return(plotlist_purrr) # subtitle list
   }
