@@ -1,9 +1,3 @@
-# ----------------------- ipmisc -----------------------------------
-
-#' @export
-#' @importFrom ipmisc set_cwd
-ipmisc::set_cwd
-
 # ----------------------- tidyverse -------------------------------------
 
 #' @export
@@ -22,14 +16,6 @@ ipmisc::`%$%`
 #' @importFrom ipmisc "%<-%"
 ipmisc::`%<-%`
 
-#' @export
-#' @importFrom ipmisc "%||%"
-ipmisc::`%||%`
-
-#' @export
-#' @importFrom ipmisc "%|%"
-ipmisc::`%|%`
-
 #' @export
 #' @importFrom ipmisc tibble
 ipmisc::tibble
@@ -41,3 +27,7 @@ ipmisc::enframe
 #' @export
 #' @importFrom ipmisc as_tibble
 ipmisc::as_tibble
+
+#' @export
+#' @importFrom correlation correlation
+correlation::correlation
