@@ -1,9 +1,9 @@
 # outlier labeling works --------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "grouping.var works across vector types",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # creating a smaller dataframe
     set.seed(123)
@@ -14,7 +14,7 @@ testthat::test_that(
       )
 
     # expect error when no grouping.var is specified
-    testthat::expect_error(
+    expect_error(
       ggstatsplot::grouped_ggbetweenstats(
         data = dat,
         x = genre,
@@ -29,13 +29,12 @@ testthat::test_that(
       y = rating,
       results.subtitle = FALSE,
       grouping.var = mpaa,
-      outlier.tagging = FALSE,
-      messages = FALSE
+      outlier.tagging = FALSE
     )
 
     # `outlier.label` is not specified
     set.seed(123)
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       ggstatsplot::grouped_ggbetweenstats(
         data = dat,
         x = genre,
@@ -49,15 +48,14 @@ testthat::test_that(
         bf.message = TRUE,
         outlier.tagging = TRUE,
         pairwise.comparisons = TRUE,
-        pairwise.annotation = "p.value",
-        messages = FALSE
+        pairwise.annotation = "p.value"
       ),
       what = "gg"
     ))
 
     # `outlier.label` is factor
     set.seed(123)
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       ggstatsplot::grouped_ggbetweenstats(
         data = dat,
         x = "genre",
@@ -66,7 +64,6 @@ testthat::test_that(
         type = "np",
         plot.type = "violin",
         pairwise.comparisons = TRUE,
-        messages = FALSE,
         outlier.tagging = TRUE,
         results.subtitle = FALSE,
         outlier.label = title
@@ -80,13 +77,12 @@ testthat::test_that(
     set.seed(123)
     dat$title <- as.character(dat$title)
 
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       ggstatsplot::grouped_ggbetweenstats(
         data = dat,
         x = "genre",
         y = "rating",
         grouping.var = mpaa,
-        messages = FALSE,
         type = "r",
         results.subtitle = FALSE,
         pairwise.comparisons = TRUE,
@@ -103,10 +99,10 @@ testthat::test_that(
 
 # subtitle output --------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "subtitle output",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     set.seed(123)
     df <- dplyr::sample_frac(forcats::gss_cat, 0.25) %>%
@@ -125,8 +121,7 @@ testthat::test_that(
         grouping.var = "marital",
         output = "subtitle",
         bf.message = FALSE,
-        k = 4,
-        messages = FALSE
+        k = 4
       )
 
 
@@ -138,10 +133,9 @@ testthat::test_that(
         y = "tvhours",
         output = "subtitle",
         bf.message = FALSE,
-        k = 4,
-        messages = FALSE
+        k = 4
       )
     # tests
-    testthat::expect_equal(ls_results$`Never married`, basic_results)
+    expect_equal(ls_results$`Never married`, basic_results)
   }
 )
